Trait gg::traits::HasId
[−]
[src]
pub trait HasId {
fn get_id(&self) -> usize;
}Allows us to verify that there is a way to get an id for this
pub trait HasId {
fn get_id(&self) -> usize;
}Allows us to verify that there is a way to get an id for this